| Title: | Easily Install and Load the 'PACTA-verse' |
|---|---|
| Description: | The 'pactaverse' is a set of packages that work to help R users implement various functionality related to the PACTA open source project. |
| Authors: | Jackson Hoffart [aut, cre, ctr] (ORCID: <https://orcid.org/0000-0002-8600-5042>), CJ Yetman [aut, ctr] (ORCID: <https://orcid.org/0000-0001-5099-9500>), Jacob Kastl [aut, ctr], Monika Furdyna [aut, ctr], Alex Axthelm [aut, ctr] (ORCID: <https://orcid.org/0000-0001-8579-8565>), RMI [cph, fnd] |
| Maintainer: | Jackson Hoffart <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-24 07:25:00 UTC |
| Source: | https://github.com/rmi-pacta/pactaverse |
This function lists all the conflicts between packages in the pactaverse and other packages that you have loaded.
pactaverse_conflicts(only = NULL)pactaverse_conflicts(only = NULL)
only |
Set this to a character vector to restrict to conflicts only with these packages. |
There are four conflicts that are deliberately ignored: intersect,
union, setequal, and setdiff from dplyr. These functions
make the base equivalents generic, so shouldn't negatively affect any
existing code.
pactaverse_conflicts()pactaverse_conflicts()
List all pactaverse dependencies
pactaverse_deps(recursive = FALSE, repos = getOption("repos"))pactaverse_deps(recursive = FALSE, repos = getOption("repos"))
recursive |
If |
repos |
The repositories to use to check for updates.
Defaults to |
Use cli::ansi_strip() to get rid of the colors.
pactaverse_logo(unicode = cli::is_utf8_output())pactaverse_logo(unicode = cli::is_utf8_output())
unicode |
Whether to use Unicode symbols. Default is |
pactaverse_logo()pactaverse_logo()
List all packages in the pactaverse
pactaverse_packages(include_self = TRUE)pactaverse_packages(include_self = TRUE)
include_self |
Include pactaverse in the list? |
pactaverse_packages()pactaverse_packages()
This function gives a quick overview of the versions of R and RStudio as well as all pactaverse packages. It's primarily designed to help you get a quick idea of what's going on when you're helping someone else debug a problem.
pactaverse_sitrep()pactaverse_sitrep()
This will check to see if all pactaverse packages (and optionally, their dependencies) are up-to-date, and will install after an interactive confirmation.
pactaverse_update(recursive = FALSE, repos = getOption("repos"))pactaverse_update(recursive = FALSE, repos = getOption("repos"))
recursive |
If |
repos |
The repositories to use to check for updates.
Defaults to |
## Not run: pactaverse_update() ## End(Not run)## Not run: pactaverse_update() ## End(Not run)